@@ -11,9 +11,17 @@ class AppConfig():
 
     def __init__(self, config):
         self.config = config
-        self.config['toggl_start_date'] = str(date.today())
+        self.set_date_interval(config)
         AppConfig.__check_config_integrity(self.config)
 
+    def set_date_interval(self, config):
+        dates = ['toggl_start_date', 'toggl_end_date']
+        for date_config in dates:
+            if date_config in config:
+                self.config[date_config] = config[date_config]
+            else:
+                self.config[date_config] = str(date.today())
+
     def get(self, config_name):
         return self.config.get(config_name)
 
@@ -35,7 +43,8 @@ class AppConfig():
     @staticmethod
     def __check_config_integrity(config):
         config_keys = ['toggl_user', 'toggl_workspace_id', 'toggl_start_date',
-                    'toggl_api_token', 'redmine_url', 'redmine_api_key']
+                       'toggl_end_date', 'toggl_api_token', 'redmine_url', 'redmine_api_key']
         for key in config_keys:
-            if config.get(key) == None:
-                raise ConfigException("There's a key missing in the configuration")
+            if key not in config:
+                raise ConfigException(
+                    "There's a key missing in the configuration")
